@@ -15,10 +15,10 @@ use syn::ext::IdentExt;
 use syn::parse::{Parse, ParseStream, Result};
 use syn::{Attribute, Ident, Type};
 
-pub const VERSION: &'static str = env!("CARGO_PKG_VERSION");
+pub const VERSION: &str = env!("CARGO_PKG_VERSION");
 
-pub const LIB_NAME: &'static str = "librust_cpp_generated.a";
-pub const MSVC_LIB_NAME: &'static str = "rust_cpp_generated.lib";
+pub const LIB_NAME: &str = "librust_cpp_generated.a";
+pub const MSVC_LIB_NAME: &str = "rust_cpp_generated.lib";
 
 pub mod flags {
     pub const IS_COPY_CONSTRUCTIBLE: u32 = 0;
@@ -34,7 +34,7 @@ pub mod kw {
 }
 
 /// This constant is expected to be a unique string within the compiled binary
-/// which preceeds a definition of the metadata. It begins with
+/// which precedes a definition of the metadata. It begins with
 /// rustcpp~metadata, which is printable to make it easier to locate when
 /// looking at a binary dump of the metadata.
 ///
@@ -76,7 +76,7 @@ pub struct Capture {
 }
 
 impl Parse for Capture {
-    /// Parse a single captured variable inside within a cpp! macro.
+    /// Parse a single captured variable inside within a `cpp!` macro.
     /// Example: `mut foo as "int"`
     fn parse(input: ParseStream) -> Result<Self> {
         Ok(Capture {
@@ -118,12 +118,12 @@ impl ClosureSig {
 pub struct Closure {
     pub sig: ClosureSig,
     pub body: TokenTree,
-    pub body_str: String, // with rust! macro replaced
+    pub body_str: String, // with `rust!` macro replaced
     pub callback_offset: u32,
 }
 
 impl Parse for Closure {
-    /// Parse the inside of a cpp! macro when this macro is a closure.
+    /// Parse the inside of a `cpp!` macro when this macro is a closure.
     /// Example: `unsafe [foo as "int"] -> u32 as "int" { /*... */ }
     fn parse(input: ParseStream) -> Result<Self> {
         input.parse::<Option<Token![unsafe]>>()?;
@@ -131,10 +131,10 @@ impl Parse for Closure {
         // Capture
         let capture_content;
         bracketed!(capture_content in input);
-        let captures = syn::punctuated::Punctuated::<Capture, Token![,]>::parse_terminated(
-            &capture_content,
-        )?.into_iter()
-            .collect();
+        let captures =
+            syn::punctuated::Punctuated::<Capture, Token![,]>::parse_terminated(&capture_content)?
+                .into_iter()
+                .collect();
 
         // Optional return type
         let (ret, cpp) = if input.peek(Token![->]) {
@@ -207,7 +207,7 @@ impl Class {
 }
 
 impl Parse for Class {
-    /// Parse the inside of a cpp_class! macro.
+    /// Parse the inside of a `cpp_class!` macro.
     /// Example: `#[derive(Default)] pub unsafe struct Foobar as "FooBar"`
     fn parse(input: ParseStream) -> Result<Self> {
         Ok(Class {
@@ -234,7 +234,7 @@ pub enum Macro {
 }
 
 impl Parse for Macro {
-    ///! Parse the inside of a cpp! macro (a literal or a closure)
+    ///! Parse the inside of a `cpp!` macro (a literal or a closure)
     fn parse(input: ParseStream) -> Result<Self> {
         if input.peek(syn::token::Brace) {
             let content;
@@ -255,7 +255,7 @@ pub struct RustInvocation {
 }
 
 impl Parse for RustInvocation {
-    /// Parse a rust! macro something looking like `rust!(ident [foo : bar as "bar"] { /*...*/ })`
+    /// Parse a `rust!` macro something looking like `rust!(ident [foo : bar as "bar"] { /*...*/ })`
     fn parse(input: ParseStream) -> Result<Self> {
         let rust_token = input.parse::<kw::rust>()?;
         input.parse::<Token![!]>()?;
@@ -278,8 +278,7 @@ impl Parse for RustInvocation {
                             let s = input.parse::<syn::LitStr>()?.value();
                             Ok((i, s))
                         },
-                    )?
-                    .into_iter()
+                    )?.into_iter()
                     .collect()
             },
             return_type: if macro_content.peek(Token![->]) {
